@@ -7,18 +7,20 @@
 # You may use and distribute this software under the same terms and conditions
 # as Perl itself.
 
-package PkgConfig::Vars;
+package
+    PkgConfig::Vars;
 # this is a namespace for .pc files to hold their variables without
 # relying on lexical scope.
 
-package PkgConfig::UDefs;
+package
+    PkgConfig::UDefs;
 # This namespace provides user-defined variables which are to override any
 # declarations within the .pc file itself.
 
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.07620_01';
+our $VERSION = '0.08220_01';
 
 require 5.006;
 
@@ -71,24 +73,70 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
     # use the defaults regardless of detected platform
 
 } elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
+
+    my $arch;
     if(-x "/usr/bin/dpkg-architecture") {
-        my $arch = `/usr/bin/dpkg-architecture -qDEB_HOST_MULTIARCH`;
+        # works if dpkg-dev is installed
+        # rt96694
+        ($arch) = map { chomp; (split /=/)[1] }
+                  grep /^DEB_HOST_MULTIARCH=/,
+                  `/usr/bin/dpkg-architecture`;
+    } elsif(-x "/usr/bin/gcc") {
+        # works if gcc is installed
+        $arch = `/usr/bin/gcc -dumpmachine`;
         chomp $arch;
+    } else {
+        my $deb_arch = `dpkg --print-architecture`;
+        if($deb_arch =~ /^amd64/) {
+            if($^O eq 'linux') {
+                $arch = 'x86_64-linux-gnu';
+            } elsif($^O eq 'gnukfreebsd') {
+                $arch = 'x86_64-kfreebsd-gnu';
+            }
+        } elsif($deb_arch =~ /^i386/) {
+            if($^O eq 'linux') {
+                $arch = 'i386-linux-gnu';
+            } elsif($^O eq 'gnukfreebsd') {
+                $arch = 'i386-kfreebsd-gnu';
+            }
+        }
+    }
+
+    if($arch) {
+        if(scalar grep /--print-foreign-architectures/, `dpkg --help`)
+        {
+            # multi arch support / Debian 7+
+            @DEFAULT_SEARCH_PATH = (
+                "/usr/local/lib/$arch/pkgconfig",
+                "/usr/local/lib/pkgconfig",
+                "/usr/local/share/pkgconfig",
+                "/usr/lib/$arch/pkgconfig",
+                "/usr/lib/pkgconfig",
+                "/usr/share/pkgconfig",
+            );
+        } else {
+        
+            @DEFAULT_SEARCH_PATH = (
+                "/usr/local/lib/pkgconfig",
+                "/usr/local/lib/pkgconfig/$arch",
+                "/usr/local/share/pkgconfig",
+                "/usr/lib/pkgconfig",
+                "/usr/lib/pkgconfig/$arch",
+                "/usr/share/pkgconfig",
+            );
+        }
+    
+    } else {
+
         @DEFAULT_SEARCH_PATH = (
-            "/usr/local/lib/$arch/pkgconfig",
             "/usr/local/lib/pkgconfig",
             "/usr/local/share/pkgconfig",
-            "/usr/lib/$arch/pkgconfig",
             "/usr/lib/pkgconfig",
             "/usr/share/pkgconfig",
         );
-    } else {
-        # TODO: the debian 6 official pkg-config also includes
-        # /usr/local/lib/pkgconfig/x86_64-linux-gnu
-        # /usr/lib/pkgconfig/x86_64-linux-gnu    
-        # but not sure if they are used
-    }
 
+    }
+    
 } elsif($^O eq 'linux' && -r "/etc/redhat-release") {
 
     if(-d "/usr/lib64/pkgconfig") {
@@ -328,6 +376,10 @@ struct(
      'print_variable' => '$',
      'print_values' => '$',
      'defined_variables' => '*%',
+     
+     # for creating PkgConfig objects with identical
+     # settings
+     'original' => '$',
     ]
 );
 
@@ -407,6 +459,8 @@ sub find {
         ['exclude_cflags', \@DEFAULT_EXCLUDE_CFLAGS]
     );
     
+    my %original = %options;
+    
     foreach (@uspecs) {
         my ($basekey,$default) = @$_;
         my $list = [ @{$options{$basekey} ||= [] } ];
@@ -423,6 +477,7 @@ sub find {
     $VarClassSerial++;
     $options{varclass} = sprintf("PkgConfig::Vars::SERIAL_%d", $VarClassSerial);
     $options{udefclass} = sprintf("PkgConfig::UDefs::SERIAL_%d", $VarClassSerial);
+    $options{original} = \%original;
     
     
     my $udefs = delete $options{VARS} || {};
@@ -664,11 +719,14 @@ sub parse_pcfile {
         $self->pkg_description( $self->_pc_var('description') );
         $self->pkg_exists(1);        
     }
-    
+
     unless ($self->no_recurse) {
         foreach (@deps) {
             my ($dep,$cmp_op,$version) = @$_;
-            $self->find_pcfile($dep);
+            $dep = "$dep $cmp_op $version" if defined $cmp_op;
+            my $other = PkgConfig->find($dep, %{ $self->original });
+            $self->append_cflags(  $other->get_cflags );
+            $self->append_ldflags( $other->get_ldflags );
         }
     }
 }
@@ -922,6 +980,7 @@ GetOptions(
     'list-all' => \my $ListAll,
     'static' => \my $UseStatic,
     'cflags' => \my $PrintCflags,
+    'cflags-only-I' => \my $PrintCflagsOnlyI,
     'exists' => \my $PrintExists,
     'atleast-version=s' => \my $AtLeastVersion,
     'exact-version=s'   => \my $ExactVersion,
@@ -983,7 +1042,7 @@ if($SilenceErrors) {
     $quiet_errors = 1;
 }
 
-my $WantFlags = ($PrintCflags || $PrintLibs || $PrintLibsOnlyL || $PrintLibsOnlyl || $PrintVersion);
+my $WantFlags = ($PrintCflags || $PrintLibs || $PrintLibsOnlyL || $PrintCflagsOnlyI || $PrintLibsOnlyl || $PrintVersion);
 
 if($WantFlags) {
     $quiet_errors = 0 unless $SilenceErrors;
@@ -1063,12 +1122,18 @@ if($PrintVersion) {
     exit(0);
 }
 
+my @print_flags;
+
 if($PrintCflags) {
-    print join(" ", $o->get_cflags) . " ";
+    @print_flags = $o->get_cflags;
+}
+
+if($PrintCflagsOnlyI) {
+    @print_flags = grep /^-I/, $o->get_cflags;
 }
 
 if($PrintLibs) {
-    print join(" ", $o->get_ldflags) . " ";
+    @print_flags = $o->get_ldflags;
 }
 
 # handle --libs-only-L and --libs-only-l but watch the case when
@@ -1076,11 +1141,12 @@ if($PrintLibs) {
 # 'ppkg-config --libs-only-l foo'
 
 if($PrintLibsOnlyl or ($PrintLibsOnlyl and $PrintLibsOnlyL)) {
-    print grep /^-l/, $o->get_ldflags;
+    @print_flags = grep /^-l/, $o->get_ldflags;
 } elsif ($PrintLibsOnlyL) {
-    print grep /^-[LR]/, $o->get_ldflags;
+    @print_flags = grep /^-[LR]/, $o->get_ldflags;
 }
 
+print $_, " " for @print_flags;
 print "\n";
 exit(0);
 
@@ -1175,6 +1241,10 @@ List all know packages.
 
 (Also) print compiler and C preprocessor flags.
 
+=head4 --cflags-only-I
+
+Prints the -I part of "--cflags"
+
 =head4 --modversion
 
 Print the version of a given package.
@@ -1218,8 +1288,6 @@ This returns the value of a variable defined in a package's .pc file.
 
 Print all defined variables found in the .pc files.
 
-
-
 =head4 --version
 
 The target version of C<pkg-config> emulated by this script
@@ -1246,8 +1314,8 @@ C<--silence-errors>
 
 =head3 ENVIRONMENT
 
-the C<PKG_CONFIG_PATH> variable is honored and used as a colon-delimited list
-of directories with contain C<.pc> files.
+the C<PKG_CONFIG_PATH> variable is honored and used as a colon-delimited 
+(semicolon-delimited on Windows) list of directories with contain C<.pc> files.
 
 =head2 MODULE OPTIONS
 
@@ -1380,6 +1448,10 @@ Example, don't install any scripts:
 
  % perl Makefile.PL --script none
 
+You can also set the environment variable PERL_PKG_CONFIG_SCRIPTS to the
+desired --script value (separating each script name with a comma C<,>) to
+ensure that upgrades of PkgConfig do the same.
+
 =head2 CAVEATS
 
 On Strawberry Perl C<ppkg-config> acts like Strawberry is the system.  
@@ -1436,6 +1508,14 @@ Another perl implementation of pkg-config
 
 An alternative C implementation
 
+=item L<pkg-config|https://github.com/ruby-gnome2/pkg-config>
+
+Pure Ruby implementation.
+
+=item L<pykg-config|https://pypi.python.org/pypi/pykg-config/1.2.0>
+
+A Python implementation.
+
 =back
 
 =head1 AUTHOR
